@@ -49,9 +49,11 @@ test_that("solve (compressed formulation, single zone)", {
        add_locked_out_constraints(locked_out) %>%
        add_default_solver(gap = 0)
   # solve problem
-  s <- solve(p)
+  s1 <- solve(p)
+  s2 <- solve(p)
   # test that solution is correct
-  expect_equal(raster::values(s), c(0, 1, 1, NA))
+  expect_equal(raster::values(s1), c(0, 1, 1, NA))
+  expect_equal(raster::values(s1), raster::values(s2))
 })
 
 test_that("compile (expanded formulation, single zone)", {
